PortInfo class

Contains info of the printer connection

Constructors

PortInfo(dynamic port)

Properties

hashCode → int
The hash code for this object.
no setterinherited
macAddress ↔ String?
MacAdress of printer
getter/setter pair
modelName ↔ String?
Model name of printer
getter/setter pair
portName ↔ String?
Port connection of printer, use this to connect to the printer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usbSerialNumber ↔ String?
USB Serial number of usb printers
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited