PrinterResponseStatus class

Response class for printer status

Constructors

PrinterResponseStatus({required bool offline, required bool coverOpen, required bool cutterError, required bool receiptPaperEmpty, String? errorMessage, required bool isSuccess, required bool overTemp, String? infoMessage, String? modelName, String? firmwareVersion})
PrinterResponseStatus.fromJson(String source)
Create from JsonString PrinterResponseStatus
factory
PrinterResponseStatus.fromMap(Map<String, dynamic> map)
Turn Map into PrinterResponseStatus
factory

Properties

coverOpen → bool
Whether the cover is open
final
cutterError → bool
Whether cutter has error
final
errorMessage → String?
Error response from printer
final
firmwareVersion → String?
Printer firmware version
final
hashCode → int
The hash code for this object.
no setteroverride
infoMessage → String?
Extra info on printer status
final
isSuccess → bool
Status command after sent to printer
final
modelName → String?
Printer model name
final
offline → bool
Whether the printer is offline
final
overTemp → bool
Whether printer is overheating
final
receiptPaperEmpty → bool
Whether printer has receipt paper
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? offline, bool? coverOpen, bool? cutterError, bool? receiptPaperEmpty, String? errorMessage, bool? isSuccess, bool? overTemp, String? infoMessage, String? modelName, String? firmwareVersion}) → PrinterResponseStatus
Creates a copy of PrinterResponseStatus but with given field replace with new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
Turn PrinterResponseStatus into JsonString
toMap() → Map<String, dynamic>
Map PrinterResponseStatus into a Map
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override