StarMicronicsModel class

Object representation of categories printers group by product line

Constructors

StarMicronicsModel({String? name, String? emulation, required List<String> models})

Properties

emulation ↔ String?
Printer's emulation
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
models ↔ List<String>
Model in the product line
getter/setter pair
name ↔ String?
Printer's product line
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited